@@ -318,6 +318,25 @@ void getParameters(ppd_file_t *ppd,int num_options,cups_option_t *options,Proces
     param.numCopies=1;
   }
 
+  if((val = cupsGetOption("ipp-attribute-fidelity",num_options,options))!=NULL) {
+    if(!strcasecmp(val,"true")||!strcasecmp(val,"yes") ||
+      !strcasecmp(val,"on"))
+      param.fidelity = true;
+  }
+
+  if((val = cupsGetOption("print-scaling",num_options,options)) != NULL) {
+    if(!strcasecmp(val,"auto"))
+      param.autoprint = true;
+    else if(!strcasecmp(val,"auto-fit"))
+      param.autofit = true;
+    else if(!strcasecmp(val,"fill"))
+      param.fillprint = true;
+    else if(!strcasecmp(val,"fit"))
+      param.fitplot = true;
+    else
+      param.cropfit = true;
+  }
+  else {
   if ((val=cupsGetOption("fitplot",num_options,options)) == NULL) {
     if ((val=cupsGetOption("fit-to-page",num_options,options)) == NULL) {
       val=cupsGetOption("ipp-attribute-fidelity",num_options,options);
@@ -326,26 +345,19 @@ void getParameters(ppd_file_t *ppd,int num_options,cups_option_t *options,Proces
   // TODO?  pstops checks =="true", pdftops !is_false  ... pstops says: fitplot only for PS (i.e. not for PDF, cmp. cgpdftopdf)
   param.fitplot=(val)&&(!is_false(val));
 
-  if((val=cupsGetOption("print-scaling",num_options,options))!=NULL) {
-    if(!strcasecmp(val,"fill")) {
-      param.fillprint=true;
-    }
-  }
-  else if((val = cupsGetOption("fill",num_options,options))!=0) {
+  if((val = cupsGetOption("fill",num_options,options))!=0) {
     if(!strcasecmp(val,"true")||!strcasecmp(val,"yes"))
     {
       param.fillprint = true;
     }
   }
-  /*
-   * crop-to-fit
-   */
   if((val = cupsGetOption("crop-to-fit",num_options,options))!= NULL){
     if(!strcasecmp(val,"true")||!strcasecmp(val,"yes"))
     {
       param.cropfit=1;
     }
   }
+  }
 
   if (ppd && (ppd->landscape < 0)) { // direction the printer rotates landscape (90 or -90)
     param.normal_landscape=ROT_270;
